You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@click.apache.org by aa...@apache.org on 2013/11/02 10:23:40 UTC

svn commit: r1538160 - in /click/trunk/click: examples/webapp/ajax/ examples/webapp/ajax/compare/ examples/webapp/ajax/content/ examples/webapp/ajax/form/ examples/webapp/ajax/scroller/ examples/webapp/ajax/table/ extras/test/org/apache/click/extras/co...

Author: aadrian
Date: Sat Nov  2 09:23:39 2013
New Revision: 1538160

URL: http://svn.apache.org/r1538160
Log:
typos and semicolons.

Modified:
    click/trunk/click/examples/webapp/ajax/ajax-behavior.htm
    click/trunk/click/examples/webapp/ajax/ajax-fallback.htm
    click/trunk/click/examples/webapp/ajax/ajax-redirect.htm
    click/trunk/click/examples/webapp/ajax/ajax-secure.htm
    click/trunk/click/examples/webapp/ajax/compare/jquery-ajax-demo.htm
    click/trunk/click/examples/webapp/ajax/compare/prototype-ajax-demo.htm
    click/trunk/click/examples/webapp/ajax/content/json-response.htm
    click/trunk/click/examples/webapp/ajax/content/xml-response.htm
    click/trunk/click/examples/webapp/ajax/form/advanced-form-ajax.js
    click/trunk/click/examples/webapp/ajax/form/simple-form-ajax.js
    click/trunk/click/examples/webapp/ajax/page-action.htm
    click/trunk/click/examples/webapp/ajax/scroller/ajax-live-scroller.js
    click/trunk/click/examples/webapp/ajax/table/table-ajax.js
    click/trunk/click/extras/test/org/apache/click/extras/control/CheckListTest.java
    click/trunk/click/extras/test/org/apache/click/extras/control/DoubleFieldTest.java
    click/trunk/click/framework/src/org/apache/click/ActionEventDispatcher.java
    click/trunk/click/framework/src/org/apache/click/PageInterceptor.java
    click/trunk/click/framework/src/org/apache/click/Stateful.java
    click/trunk/click/framework/src/org/apache/click/ajax/AjaxBehavior.java
    click/trunk/click/framework/src/org/apache/click/control/AbstractLink.java
    click/trunk/click/framework/src/org/apache/click/control/ActionButton.java
    click/trunk/click/framework/src/org/apache/click/control/Select.java
    click/trunk/click/framework/src/org/apache/click/service/ConfigService.java
    click/trunk/click/framework/src/org/apache/click/service/XmlConfigService.java
    click/trunk/click/framework/src/org/apache/click/util/ClickUtils.java
    click/trunk/click/framework/src/org/apache/click/util/PropertyUtils.java
    click/trunk/click/framework/test/org/apache/click/control/AbstractContainerTest.java
    click/trunk/click/framework/test/org/apache/click/control/RadioGroupTest.java
    click/trunk/click/framework/test/org/apache/click/control/RadioTest.java
    click/trunk/click/framework/test/org/apache/click/control/SubmitTest.java
    click/trunk/click/framework/test/org/apache/click/service/XmlConfigServiceTest.java

Modified: click/trunk/click/examples/webapp/ajax/ajax-behavior.htm
URL: http://svn.apache.org/viewvc/click/trunk/click/examples/webapp/ajax/ajax-behavior.htm?rev=1538160&r1=1538159&r2=1538160&view=diff
==============================================================================
--- click/trunk/click/examples/webapp/ajax/ajax-behavior.htm (original)
+++ click/trunk/click/examples/webapp/ajax/ajax-behavior.htm Sat Nov  2 09:23:39 2013
@@ -45,7 +45,7 @@ Click $link to make an Ajax request to t
             // Prevent the default browser behavior of navigating to the link
             return false;
         })
-    })
+    });
 
     function makeRequest() {
         var link = jQuery('#link-id');

Modified: click/trunk/click/examples/webapp/ajax/ajax-fallback.htm
URL: http://svn.apache.org/viewvc/click/trunk/click/examples/webapp/ajax/ajax-fallback.htm?rev=1538160&r1=1538159&r2=1538160&view=diff
==============================================================================
--- click/trunk/click/examples/webapp/ajax/ajax-fallback.htm (original)
+++ click/trunk/click/examples/webapp/ajax/ajax-fallback.htm Sat Nov  2 09:23:39 2013
@@ -54,7 +54,7 @@ behavior in action)
             // Prevent the default browser behavior of navigating to the link
             return false;
         })
-    })
+    });
 
     function makeRequest() {
         var link = jQuery('#link-id');

Modified: click/trunk/click/examples/webapp/ajax/ajax-redirect.htm
URL: http://svn.apache.org/viewvc/click/trunk/click/examples/webapp/ajax/ajax-redirect.htm?rev=1538160&r1=1538159&r2=1538160&view=diff
==============================================================================
--- click/trunk/click/examples/webapp/ajax/ajax-redirect.htm (original)
+++ click/trunk/click/examples/webapp/ajax/ajax-redirect.htm Sat Nov  2 09:23:39 2013
@@ -60,7 +60,7 @@ by setting the value of <tt>window.locat
             // Prevent the default browser behavior of navigating to the link
             return false;
         })
-    })
+    });
 
     function redirectLinkClicked() {
         var link = jQuery('#redirectLinkId');

Modified: click/trunk/click/examples/webapp/ajax/ajax-secure.htm
URL: http://svn.apache.org/viewvc/click/trunk/click/examples/webapp/ajax/ajax-secure.htm?rev=1538160&r1=1538159&r2=1538160&view=diff
==============================================================================
--- click/trunk/click/examples/webapp/ajax/ajax-secure.htm (original)
+++ click/trunk/click/examples/webapp/ajax/ajax-secure.htm Sat Nov  2 09:23:39 2013
@@ -42,7 +42,7 @@ Clicking the link will show a permission
 
     // Register a function that is invoked as soon as the DOM is loaded
     jQuery(document).ready(function() {
-        var resultElm = jQuery("#result")
+        var resultElm = jQuery("#result");
 
         // Hide the result div initially if it contains no content
         if (jQuery.trim(resultElm.text()).length == 0) {
@@ -58,9 +58,9 @@ Clicking the link will show a permission
 
             // Prevent the default browser behavior of navigating to the link
             return false;
-        })
+        });
 
- // Register a 'click' handler that makes an Ajax request
+        // Register a 'click' handler that makes an Ajax request
         jQuery("#secureLinkWithMessageId").click(function(event){
             // Make ajax request
             messageLinkClicked();
@@ -68,7 +68,7 @@ Clicking the link will show a permission
             // Prevent the default browser behavior of navigating to the link
             return false;
         })
-    })
+    });
 
     function redirectLinkClicked() {
         var link = jQuery('#secureLinkWithRedirectId');

Modified: click/trunk/click/examples/webapp/ajax/compare/jquery-ajax-demo.htm
URL: http://svn.apache.org/viewvc/click/trunk/click/examples/webapp/ajax/compare/jquery-ajax-demo.htm?rev=1538160&r1=1538159&r2=1538160&view=diff
==============================================================================
--- click/trunk/click/examples/webapp/ajax/compare/jquery-ajax-demo.htm (original)
+++ click/trunk/click/examples/webapp/ajax/compare/jquery-ajax-demo.htm Sat Nov  2 09:23:39 2013
@@ -48,7 +48,7 @@ $link
             // Prevent the default browser behavior of navigating to the link
             return false;
         })
-    })
+    });
 
     function makeRequest() {
         // The URL to make the Ajax request on should include enough information

Modified: click/trunk/click/examples/webapp/ajax/compare/prototype-ajax-demo.htm
URL: http://svn.apache.org/viewvc/click/trunk/click/examples/webapp/ajax/compare/prototype-ajax-demo.htm?rev=1538160&r1=1538159&r2=1538160&view=diff
==============================================================================
--- click/trunk/click/examples/webapp/ajax/compare/prototype-ajax-demo.htm (original)
+++ click/trunk/click/examples/webapp/ajax/compare/prototype-ajax-demo.htm Sat Nov  2 09:23:39 2013
@@ -47,7 +47,7 @@ $link
             // Prevent the default browser behavior of navigating to the link
             event.preventDefault();
         })
-    })
+    });
 
     function makeRequest() {
         // The URL to make the Ajax request on should include enough information

Modified: click/trunk/click/examples/webapp/ajax/content/json-response.htm
URL: http://svn.apache.org/viewvc/click/trunk/click/examples/webapp/ajax/content/json-response.htm?rev=1538160&r1=1538159&r2=1538160&view=diff
==============================================================================
--- click/trunk/click/examples/webapp/ajax/content/json-response.htm (original)
+++ click/trunk/click/examples/webapp/ajax/content/json-response.htm Sat Nov  2 09:23:39 2013
@@ -43,7 +43,7 @@ Click $link to call the server using Aja
             // Prevent the default browser behavior of navigating to the link
             return false;
         })
-    })
+    });
 
     function makeRequest() {
         var link = jQuery('#link-id');

Modified: click/trunk/click/examples/webapp/ajax/content/xml-response.htm
URL: http://svn.apache.org/viewvc/click/trunk/click/examples/webapp/ajax/content/xml-response.htm?rev=1538160&r1=1538159&r2=1538160&view=diff
==============================================================================
--- click/trunk/click/examples/webapp/ajax/content/xml-response.htm (original)
+++ click/trunk/click/examples/webapp/ajax/content/xml-response.htm Sat Nov  2 09:23:39 2013
@@ -42,7 +42,7 @@ Click $link to call the server using Aja
             // Prevent the default browser behavior of navigating to the link
             return false;
         })
-    })
+    });
 
     function makeRequest() {
         var link = jQuery('#link-id');

Modified: click/trunk/click/examples/webapp/ajax/form/advanced-form-ajax.js
URL: http://svn.apache.org/viewvc/click/trunk/click/examples/webapp/ajax/form/advanced-form-ajax.js?rev=1538160&r1=1538159&r2=1538160&view=diff
==============================================================================
--- click/trunk/click/examples/webapp/ajax/form/advanced-form-ajax.js (original)
+++ click/trunk/click/examples/webapp/ajax/form/advanced-form-ajax.js Sat Nov  2 09:23:39 2013
@@ -37,7 +37,7 @@ jQuery(document).ready(function() {
         // Prevent the default browser behavior of navigating to the link
         return false;
     })
-})
+});
 
 function postForm(event) {
     // Retrieve the Form and submit button elements

Modified: click/trunk/click/examples/webapp/ajax/form/simple-form-ajax.js
URL: http://svn.apache.org/viewvc/click/trunk/click/examples/webapp/ajax/form/simple-form-ajax.js?rev=1538160&r1=1538159&r2=1538160&view=diff
==============================================================================
--- click/trunk/click/examples/webapp/ajax/form/simple-form-ajax.js (original)
+++ click/trunk/click/examples/webapp/ajax/form/simple-form-ajax.js Sat Nov  2 09:23:39 2013
@@ -28,7 +28,7 @@ jQuery(document).ready(function() {
         // Prevent the default browser behavior of navigating to the link
         return false;
     })
-})
+});
 
 function postForm(event) {
     // Retrieve the Form and submit button elements

Modified: click/trunk/click/examples/webapp/ajax/page-action.htm
URL: http://svn.apache.org/viewvc/click/trunk/click/examples/webapp/ajax/page-action.htm?rev=1538160&r1=1538159&r2=1538160&view=diff
==============================================================================
--- click/trunk/click/examples/webapp/ajax/page-action.htm (original)
+++ click/trunk/click/examples/webapp/ajax/page-action.htm Sat Nov  2 09:23:39 2013
@@ -46,7 +46,7 @@ Click $link to call the server using Aja
             // Prevent the default browser behavior of navigating to the link
             return false;
         })
-    })
+    });
 
     function makeRequest() {
         var link = jQuery('#link-id');

Modified: click/trunk/click/examples/webapp/ajax/scroller/ajax-live-scroller.js
URL: http://svn.apache.org/viewvc/click/trunk/click/examples/webapp/ajax/scroller/ajax-live-scroller.js?rev=1538160&r1=1538159&r2=1538160&view=diff
==============================================================================
--- click/trunk/click/examples/webapp/ajax/scroller/ajax-live-scroller.js (original)
+++ click/trunk/click/examples/webapp/ajax/scroller/ajax-live-scroller.js Sat Nov  2 09:23:39 2013
@@ -88,4 +88,4 @@ $(document).ready(function(){
     function getFetchThreshold() {
         return 0.85 * jQuery(document).height() - jQuery(window).height();
     }
-})
+});

Modified: click/trunk/click/examples/webapp/ajax/table/table-ajax.js
URL: http://svn.apache.org/viewvc/click/trunk/click/examples/webapp/ajax/table/table-ajax.js?rev=1538160&r1=1538159&r2=1538160&view=diff
==============================================================================
--- click/trunk/click/examples/webapp/ajax/table/table-ajax.js (original)
+++ click/trunk/click/examples/webapp/ajax/table/table-ajax.js Sat Nov  2 09:23:39 2013
@@ -36,7 +36,7 @@ jQuery(document).ready(function() {
 
         // Prevent the default browser behavior of navigating to the link
         event.preventDefault();
-    })
+    });
 
     // Register a 'live' click handler on the sorting links of the table header (<th>),
     // as well as the paging links on the <div> banner.
@@ -49,7 +49,7 @@ jQuery(document).ready(function() {
         // Prevent the default browser behavior of navigating to the link
         return false;
     })
-})
+});
 
 function editOrDeleteCustomer(event) {
     var link = jQuery(event.currentTarget);

Modified: click/trunk/click/extras/test/org/apache/click/extras/control/CheckListTest.java
URL: http://svn.apache.org/viewvc/click/trunk/click/extras/test/org/apache/click/extras/control/CheckListTest.java?rev=1538160&r1=1538159&r2=1538160&view=diff
==============================================================================
--- click/trunk/click/extras/test/org/apache/click/extras/control/CheckListTest.java (original)
+++ click/trunk/click/extras/test/org/apache/click/extras/control/CheckListTest.java Sat Nov  2 09:23:39 2013
@@ -153,7 +153,7 @@ public class CheckListTest extends TestC
     }
 
     /**
-     * Check that a readonly CheckList uses diabled attribute instead of
+     * Check that a readonly CheckList uses disabled attribute instead of
      * readonly attribute.
      *
      * CLK-751

Modified: click/trunk/click/extras/test/org/apache/click/extras/control/DoubleFieldTest.java
URL: http://svn.apache.org/viewvc/click/trunk/click/extras/test/org/apache/click/extras/control/DoubleFieldTest.java?rev=1538160&r1=1538159&r2=1538160&view=diff
==============================================================================
--- click/trunk/click/extras/test/org/apache/click/extras/control/DoubleFieldTest.java (original)
+++ click/trunk/click/extras/test/org/apache/click/extras/control/DoubleFieldTest.java Sat Nov  2 09:23:39 2013
@@ -132,7 +132,7 @@ public class DoubleFieldTest extends Tes
         assertEquals("20", doubleField.getValue());
         assertEquals(new Double(20), doubleField.getValueObject());
 
-        // Test requried value larger than max value
+        // Test required value larger than max value
         doubleField.setMaxValue(21);
         assertTrue(doubleField.onProcess());
         assertTrue(doubleField.isValid());

Modified: click/trunk/click/framework/src/org/apache/click/ActionEventDispatcher.java
URL: http://svn.apache.org/viewvc/click/trunk/click/framework/src/org/apache/click/ActionEventDispatcher.java?rev=1538160&r1=1538159&r2=1538160&view=diff
==============================================================================
--- click/trunk/click/framework/src/org/apache/click/PageInterceptor.java (original)
+++ click/trunk/click/framework/src/org/apache/click/PageInterceptor.java Sat Nov  2 09:23:39 2013
@@ -49,7 +49,7 @@ package org.apache.click;
  * <p/>
  * Note application scope interceptors are more efficient that request scope
  * interceptors, but you are responsible for ensuring that they are thread safe
- * and support reentrant method invocations as multiple page requests are
+ * and support re-entrant method invocations as multiple page requests are
  * processed at the same time.
  *
  * <h3><a name="configuration"></a>Configuration</h3>

Modified: click/trunk/click/framework/src/org/apache/click/Stateful.java
URL: http://svn.apache.org/viewvc/click/trunk/click/framework/src/org/apache/click/Stateful.java?rev=1538160&r1=1538159&r2=1538160&view=diff
==============================================================================
--- click/trunk/click/framework/src/org/apache/click/Stateful.java (original)
+++ click/trunk/click/framework/src/org/apache/click/Stateful.java Sat Nov  2 09:23:39 2013
@@ -132,7 +132,7 @@ public interface Stateful {
      *     int storedNumber = ((Integer) stateArray[1]).intValue();
      *     setNumber(storedNumber);
      *
-     *     boolean storedBoolen = ((Boolean) stateArray[2]).booleanValue();
+     *     boolean storedBoolean = ((Boolean) stateArray[2]).booleanValue();
      *     setBoolean(storedBoolean);
      * } </pre>
      *

Modified: click/trunk/click/framework/src/org/apache/click/ajax/AjaxBehavior.java
URL: http://svn.apache.org/viewvc/click/trunk/click/framework/src/org/apache/click/ajax/AjaxBehavior.java?rev=1538160&r1=1538159&r2=1538160&view=diff
==============================================================================
--- click/trunk/click/framework/src/org/apache/click/ajax/AjaxBehavior.java (original)
+++ click/trunk/click/framework/src/org/apache/click/ajax/AjaxBehavior.java Sat Nov  2 09:23:39 2013
@@ -46,7 +46,7 @@ public interface AjaxBehavior extends Be
      * <pre class="prettyprint">
      * public void onInit() {
      *     ActionLink link = new ActionLink("link");
-     *     link.addBehaior(new DefaultAjaxBehavior() {
+     *     link.addBehavior(new DefaultAjaxBehavior() {
      *
      *         public ActionResult onAction(Control source) {
      *             ActionResult result = new ActionResult("&lt;h1&gt;Hello world&lt;/h1&gt;", ActionResult.HTML);

Modified: click/trunk/click/framework/src/org/apache/click/control/AbstractLink.java
URL: http://svn.apache.org/viewvc/click/trunk/click/framework/src/org/apache/click/control/AbstractLink.java?rev=1538160&r1=1538159&r2=1538160&view=diff
==============================================================================
--- click/trunk/click/framework/src/org/apache/click/control/AbstractLink.java (original)
+++ click/trunk/click/framework/src/org/apache/click/control/AbstractLink.java Sat Nov  2 09:23:39 2013
@@ -802,7 +802,7 @@ public abstract class AbstractLink exten
             // A null value can only occur for Ajax requests which processes
             // parameters defined on the link, not the incoming parameters.
             // The reason for not processing the null value is because it would
-            // nullify parametesr that was set during onInit
+            // nullify the parameter that was set during onInit
             if (values == null) {
                 continue;
             }

Modified: click/trunk/click/framework/src/org/apache/click/control/ActionButton.java
URL: http://svn.apache.org/viewvc/click/trunk/click/framework/src/org/apache/click/control/ActionButton.java?rev=1538160&r1=1538159&r2=1538160&view=diff
==============================================================================
--- click/trunk/click/framework/src/org/apache/click/control/ActionButton.java (original)
+++ click/trunk/click/framework/src/org/apache/click/control/ActionButton.java Sat Nov  2 09:23:39 2013
@@ -621,7 +621,7 @@ public class ActionButton extends Button
             // A null value can only occur for Ajax requests which processes
             // parameters defined on the button, not the incoming parameters.
             // The reason for not processing the null value is because it would
-            // nullify parametesr that was set during onInit
+            // nullify the parameter that was set during onInit
             if (values == null) {
                 continue;
             }

Modified: click/trunk/click/framework/src/org/apache/click/control/Select.java
URL: http://svn.apache.org/viewvc/click/trunk/click/framework/src/org/apache/click/control/Select.java?rev=1538160&r1=1538159&r2=1538160&view=diff
==============================================================================
--- click/trunk/click/framework/src/org/apache/click/control/Select.java (original)
+++ click/trunk/click/framework/src/org/apache/click/control/Select.java Sat Nov  2 09:23:39 2013
@@ -129,7 +129,7 @@ import org.apache.click.util.HtmlStringB
  *     private Select locationSelect = new Select("location");
  *
  *     public LocationPage() {
- *         locationSelect.setMutliple(true);
+ *         locationSelect.setMultiple(true);
  *         locationSelect.setRequired(true);
  *         locationSelect.setSize(7);
  *         locationSelect.add("QLD");
@@ -157,7 +157,7 @@ import org.apache.click.util.HtmlStringB
  * <table class='form'>
  * <tr>
  * <td align='left'><label >Location</label><font color="red">*</font></td>
- * <td align='left'><select name='location'size='7' multiple ><option value='QLD'>QLD</option><option value='NSW'>NSW</option><option value='NT'>NT</option><option value='SA'>SA</option><option value='TAS'>TAS</option><option value='VIC'>VIC</option><option value='WA'>WA</option></select></td>
+ * <td align='left'><select name='location' size='7' multiple ><option value='QLD'>QLD</option><option value='NSW'>NSW</option><option value='NT'>NT</option><option value='SA'>SA</option><option value='TAS'>TAS</option><option value='VIC'>VIC</option><option value='WA'>WA</option></select></td>
  * </tr>
  * <tr><td colspan='2'>&nbsp;</td></tr>
  * <tr align='left'><td colspan='2'><input type='submit' value='  OK  '/></td></tr>
@@ -215,7 +215,7 @@ import org.apache.click.util.HtmlStringB
  * this problem you can set a
  * {@link #setDataProvider(org.apache.click.dataprovider.DataProvider) dataProvider}
  * which allows the Select to fetch data when needed. This is
- * particularly useful if retrieveing Select data is expensive e.g. loading
+ * particularly useful if retrieving Select data is expensive e.g. loading
  * from a database.
  * <p/>
  * Below is a simple example:

Modified: click/trunk/click/framework/src/org/apache/click/service/ConfigService.java
URL: http://svn.apache.org/viewvc/click/trunk/click/framework/src/org/apache/click/service/ConfigService.java?rev=1538160&r1=1538159&r2=1538160&view=diff
==============================================================================
--- click/trunk/click/framework/src/org/apache/click/service/ConfigService.java (original)
+++ click/trunk/click/framework/src/org/apache/click/service/ConfigService.java Sat Nov  2 09:23:39 2013
@@ -88,7 +88,7 @@ import org.apache.click.util.Format;
  *
  *     <context-param>
  *         <param-name>config-service-class</param-name>
- *         <param-value>com.mycorp.service.CustomConfigSerivce</param-value>
+ *         <param-value>com.mycorp.service.CustomConfigService</param-value>
  *     </context-param>
  *
  * ...
@@ -119,7 +119,7 @@ public interface ConfigService {
     public static final String NOT_FOUND_PATH = "/click/not-found.htm";
 
     /** The page auto binding mode. */
-    public enum AutoBinding { DEFAULT, ANNOTATION, NONE };
+    public enum AutoBinding { DEFAULT, ANNOTATION, NONE }
 
     /**
      * The servlet context attribute name. The ClickServlet stores the

Modified: click/trunk/click/framework/src/org/apache/click/service/XmlConfigService.java
URL: http://svn.apache.org/viewvc/click/trunk/click/framework/src/org/apache/click/service/XmlConfigService.java?rev=1538160&r1=1538159&r2=1538160&view=diff
==============================================================================
--- click/trunk/click/framework/src/org/apache/click/service/XmlConfigService.java (original)
+++ click/trunk/click/framework/src/org/apache/click/service/XmlConfigService.java Sat Nov  2 09:23:39 2013
@@ -354,7 +354,7 @@ public class XmlConfigService implements
     }
 
     /**
-     * @see ConfigService#getProperyService()
+     * @see ConfigService#getPropertyService()
      *
      * @return the application property service.
      */

Modified: click/trunk/click/framework/src/org/apache/click/util/ClickUtils.java
URL: http://svn.apache.org/viewvc/click/trunk/click/framework/src/org/apache/click/util/ClickUtils.java?rev=1538160&r1=1538159&r2=1538160&view=diff
==============================================================================
--- click/trunk/click/framework/src/org/apache/click/util/ClickUtils.java (original)
+++ click/trunk/click/framework/src/org/apache/click/util/ClickUtils.java Sat Nov  2 09:23:39 2013
@@ -2621,7 +2621,7 @@ public class ClickUtils {
                 // If this was the last state for the page, remove the page state map
                 context.removeSessionAttribute(resourcePath);
             } else {
-                // Check if control state was emoved
+                // Check if control state was removed
                 if (pop != null) {
                     // If control state was removed, set session attribute to force
                     // session replication in a cluster

Modified: click/trunk/click/framework/src/org/apache/click/util/PropertyUtils.java
URL: http://svn.apache.org/viewvc/click/trunk/click/framework/src/org/apache/click/util/PropertyUtils.java?rev=1538160&r1=1538159&r2=1538160&view=diff
==============================================================================
--- click/trunk/click/framework/src/org/apache/click/util/PropertyUtils.java (original)
+++ click/trunk/click/framework/src/org/apache/click/util/PropertyUtils.java Sat Nov  2 09:23:39 2013
@@ -103,7 +103,7 @@ public class PropertyUtils {
      * @return the property value for the given source object and property name
      */
     public static Object getValue(Object source, String name, Map cache) {
-        Validate.notNull(cache, "Null cache paramenter");
+        Validate.notNull(cache, "Null cache parameter");
 
         String basePart = name;
         String remainingPart = null;

Modified: click/trunk/click/framework/test/org/apache/click/control/AbstractContainerTest.java
URL: http://svn.apache.org/viewvc/click/trunk/click/framework/test/org/apache/click/control/AbstractContainerTest.java?rev=1538160&r1=1538159&r2=1538160&view=diff
==============================================================================
--- click/trunk/click/framework/test/org/apache/click/control/AbstractContainerTest.java (original)
+++ click/trunk/click/framework/test/org/apache/click/control/AbstractContainerTest.java Sat Nov  2 09:23:39 2013
@@ -30,7 +30,7 @@ public class AbstractContainerTest exten
      * Test AbstractContainer#add(Control) and #insert(Control, int)
      * pre conditions.
      */
-    public void testInsertPreCondistion() {
+    public void testInsertPreCondition() {
         MockContext.initContext();
         AbstractContainer container = new AbstractContainer("form") {
             private static final long serialVersionUID = 1L;

Modified: click/trunk/click/framework/test/org/apache/click/control/RadioGroupTest.java
URL: http://svn.apache.org/viewvc/click/trunk/click/framework/test/org/apache/click/control/RadioGroupTest.java?rev=1538160&r1=1538159&r2=1538160&view=diff
==============================================================================
--- click/trunk/click/framework/test/org/apache/click/control/RadioGroupTest.java (original)
+++ click/trunk/click/framework/test/org/apache/click/control/RadioGroupTest.java Sat Nov  2 09:23:39 2013
@@ -122,7 +122,7 @@ public class RadioGroupTest extends Test
     }
 
     /**
-     * Coverage test of addAll(Colelction<Object>).
+     * Coverage test of addAll(Collection<Object>).
      */
     public void testAddAllObject() {
         MockContext.initContext();
@@ -157,7 +157,7 @@ public class RadioGroupTest extends Test
     }
     
     /**
-     * Coverage test of addAll(Colelction<Object>).
+     * Coverage test of addAll(Collection<Object>).
      */
     public void testFocusJs() {
         MockContext.initContext();

Modified: click/trunk/click/framework/test/org/apache/click/control/RadioTest.java
URL: http://svn.apache.org/viewvc/click/trunk/click/framework/test/org/apache/click/control/RadioTest.java?rev=1538160&r1=1538159&r2=1538160&view=diff
==============================================================================
--- click/trunk/click/framework/test/org/apache/click/control/RadioTest.java (original)
+++ click/trunk/click/framework/test/org/apache/click/control/RadioTest.java Sat Nov  2 09:23:39 2013
@@ -104,7 +104,7 @@ public class RadioTest extends TestCase 
         assertTrue(button.isValid());
         assertFalse(button.isDisabled());
         
-        // Diasabled button without request param
+        // Disabled button without request param
         request.removeParameter("button");
         button.setDisabled(true);
         assertTrue(button.onProcess());

Modified: click/trunk/click/framework/test/org/apache/click/control/SubmitTest.java
URL: http://svn.apache.org/viewvc/click/trunk/click/framework/test/org/apache/click/control/SubmitTest.java?rev=1538160&r1=1538159&r2=1538160&view=diff
==============================================================================
--- click/trunk/click/framework/test/org/apache/click/control/SubmitTest.java (original)
+++ click/trunk/click/framework/test/org/apache/click/control/SubmitTest.java Sat Nov  2 09:23:39 2013
@@ -67,7 +67,7 @@ public class SubmitTest extends TestCase
         assertTrue(button.isValid());
         assertFalse(button.isDisabled());
 
-        // Diasabled button without request param
+        // Disabled button without request param
         request.removeParameter("button");
         button.setDisabled(true);
         assertTrue(button.onProcess());

Modified: click/trunk/click/framework/test/org/apache/click/service/XmlConfigServiceTest.java
URL: http://svn.apache.org/viewvc/click/trunk/click/framework/test/org/apache/click/service/XmlConfigServiceTest.java?rev=1538160&r1=1538159&r2=1538160&view=diff
==============================================================================
--- click/trunk/click/framework/test/org/apache/click/service/XmlConfigServiceTest.java (original)
+++ click/trunk/click/framework/test/org/apache/click/service/XmlConfigServiceTest.java Sat Nov  2 09:23:39 2013
@@ -410,7 +410,7 @@ public class XmlConfigServiceTest extend
         PrintStream pstr = makeXmlStream(tmpdir, "WEB-INF/click.xml");
         pstr.println("<click-app>");
 
-        // Dclare the pages package
+        // Declare the pages package
                 pstr.println("<pages package='org.apache.click.pages'/>");
         pstr.println("<pages package='org.apache.click.pages'>");
--- click/trunk/click/framework/src/org/apache/click/ActionEventDispatcher.java (original)
+++ click/trunk/click/framework/src/org/apache/click/ActionEventDispatcher.java Sat Nov  2 09:23:39 2013
@@ -269,15 +269,15 @@ public class ActionEventDispatcher {
      * @see #fireAjaxBehaviors(org.apache.click.Context, org.apache.click.Control)
      *
      * @param context the request context
      * @param ajaxBbehaviorSourceSet the set of controls with attached AjaxBehaviors
      *
      * @return true if the page should continue processing, false otherwise
      */
-    protected boolean fireAjaxBehaviors(Context context, Set<Control> ajaxBbehaviorSourceSet) {
+    protected boolean fireAjaxBehaviors(Context context, Set<Control> ajaxBehaviorSourceSet) {
 
         boolean continueProcessing = true;
 
-        for (Iterator<Control> it = ajaxBbehaviorSourceSet.iterator(); it.hasNext();) {
+        for (Iterator<Control> it = ajaxBehaviorSourceSet.iterator(); it.hasNext();) {
             Control source = it.next();
 
             // Pop the first entry in the set
@@ -369,7 +369,7 @@ public class ActionEventDispatcher {
                             if (behaviorActionResult == null) {
                                 buffer.append(" (ActionResult is null and will be ignored)");
                             } else {
-                                buffer.append(" (ActionResult will be ignored since another AjaxBehavior already retuned a non-null ActionResult)");
+                                buffer.append(" (ActionResult will be ignored since another AjaxBehavior already returned a non-null ActionResult)");
                             }
                         }
 
@@ -269,15 +269,15 @@ public class ActionEventDispatcher {
      *
      * @param context the request context
-     * @param ajaxBbehaviorSourceSet the set of controls with attached AjaxBehaviors
+     * @param ajaxBehaviorSourceSet the set of controls with attached AjaxBehaviors
      *
      * @return true if the page should continue processing, false otherwise

Modified: click/trunk/click/framework/src/org/apache/click/PageInterceptor.java
URL: http://svn.apache.org/viewvc/click/trunk/click/framework/src/org/apache/click/PageInterceptor.java?rev=1538160&r1=1538159&r2=1538160&view=diff
==============================================================================